@@ -5,8 +5,11 @@ conformance_test <- function(q, expected_number) {
   )
 }
 
-test_that("Conformance Test 7", {
-  q <- rstac::stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
+test_that("doc_conformance Test 7", {
+  skip_if({
+    httr::http_error(httr::HEAD("https://cql2test.ldproxy.net/ne110m4cql2"))
+  }, "Test server is offline")
+  q <- stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
                    force_version = "0.9.0")
   conformance_test(
     q = ext_filter(
@@ -38,10 +41,10 @@ test_that("Conformance Test 7", {
                  datetime < "2019-02-02")
   res <- post_request(res)
 
-  expect_s3_class(res, "STACItemCollection")
+  expect_s3_class(res, "doc_items")
   res2 <- items_next(res)
-  expect_s3_class(res2, "STACItemCollection")
-  expect_gt(object = items_length(res2), expected = items_length(res))
+  expect_s3_class(res2, "doc_items")
+  expect_equal(object = items_length(res2), expected = items_length(res))
 
   conformance_test(
     q = ext_filter(
@@ -252,8 +255,11 @@ test_that("Conformance Test 7", {
   )
 })
 
-test_that("Conformance Test 12", {
-  q <- rstac::stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
+test_that("doc_conformance Test 12", {
+  skip_if({
+    httr::http_error(httr::HEAD("https://cql2test.ldproxy.net/ne110m4cql2"))
+  }, "Test server is offline")
+  q <- stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
                    force_version = "0.9.0")
   conformance_test(
     q = ext_filter(
@@ -370,8 +376,11 @@ test_that("Conformance Test 12", {
   )
 })
 
-test_that("Conformance Test 16", {
-  q <- rstac::stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
+test_that("doc_conformance Test 16", {
+  skip_if({
+    httr::http_error(httr::HEAD("https://cql2test.ldproxy.net/ne110m4cql2"))
+  }, "Test server is offline")
+  q <- stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
                    force_version = "0.9.0")
 
   conformance_test(
@@ -457,8 +466,11 @@ test_that("Conformance Test 16", {
   )
 })
 
-test_that("Conformance Test 25", {
-  q <- rstac::stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
+test_that("doc_conformance Test 25", {
+  skip_if({
+    httr::http_error(httr::HEAD("https://cql2test.ldproxy.net/ne110m4cql2"))
+  }, "Test server is offline")
+  q <- stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
                    force_version = "0.9.0")
 
   polygon <- list(
@@ -532,8 +544,11 @@ test_that("Conformance Test 25", {
   )
 })
 
-test_that("Conformance Test 34", {
-  q <- rstac::stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
+test_that("doc_conformance Test 34", {
+  skip_if({
+    httr::http_error(httr::HEAD("https://cql2test.ldproxy.net/ne110m4cql2"))
+  }, "Test server is offline")
+  q <- stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
                    force_version = "0.9.0")
   polygon <- list(
     type = "Polygon",
@@ -685,8 +700,11 @@ test_that("Conformance Test 34", {
   )
 })
 
-test_that("Conformance Test 38", {
-  q <- rstac::stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
+test_that("doc_conformance Test 38", {
+  skip_if({
+    httr::http_error(httr::HEAD("https://cql2test.ldproxy.net/ne110m4cql2"))
+  }, "Test server is offline")
+  q <- stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
                    force_version = "0.9.0")
 
   conformance_test(
@@ -874,8 +892,11 @@ test_that("Conformance Test 38", {
   )
 })
 
-test_that("Conformance Test 45", {
-  q <- rstac::stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
+test_that("doc_conformance Test 45", {
+  skip_if({
+    httr::http_error(httr::HEAD("https://cql2test.ldproxy.net/ne110m4cql2"))
+  }, "Test server is offline")
+  q <- stac(base_url = "https://cql2test.ldproxy.net/ne110m4cql2",
                    force_version = "0.9.0")
   conformance_test(
     q = ext_filter(
